@@ -17,7 +17,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
 */
 
-#include "nccmp_common.h"
+#include <nccmp_common.h>
 
 void* 
 xmalloc(size_t num)
